from datetime import datetime
from typing import List, Optional, Dict, Any

from janis_core import *
from janis_core.types.common_data_types import Boolean, File, Int, String

Prove_V0_1_0 = CommandToolBuilder(tool="prove", base_command=["prove"], inputs=[ToolInput(tag="in_verbose", input_type=Boolean(optional=True), prefix="--verbose", doc=InputDocumentation(doc="Print all test lines.")), ToolInput(tag="in_lib", input_type=Boolean(optional=True), prefix="--lib", doc=InputDocumentation(doc="Add 'lib' to the path for your tests (-Ilib).")), ToolInput(tag="in_blib", input_type=Boolean(optional=True), prefix="--blib", doc=InputDocumentation(doc="Add 'blib/lib' and 'blib/arch' to the path for\nyour tests")), ToolInput(tag="in_shuffle", input_type=Boolean(optional=True), prefix="--shuffle", doc=InputDocumentation(doc="Run the tests in random order.")), ToolInput(tag="in_color", input_type=Boolean(optional=True), prefix="--color", doc=InputDocumentation(doc="Colored test output (default).")), ToolInput(tag="in_no_color", input_type=Boolean(optional=True), prefix="--nocolor", doc=InputDocumentation(doc="Do not color test output.")), ToolInput(tag="in_count", input_type=Boolean(optional=True), prefix="--count", doc=InputDocumentation(doc="Show the X/Y test count when not verbose\n(default)")), ToolInput(tag="in_no_count", input_type=Boolean(optional=True), prefix="--nocount", doc=InputDocumentation(doc="Disable the X/Y test count.")), ToolInput(tag="in_dry", input_type=Boolean(optional=True), prefix="--dry", doc=InputDocumentation(doc="Dry run. Show test that would have run.")), ToolInput(tag="in_failures", input_type=Boolean(optional=True), prefix="--failures", doc=InputDocumentation(doc="Show failed tests.")), ToolInput(tag="in_comments", input_type=Boolean(optional=True), prefix="--comments", doc=InputDocumentation(doc="Show comments.")), ToolInput(tag="in_ignore_exit", input_type=Boolean(optional=True), prefix="--ignore-exit", doc=InputDocumentation(doc="Ignore exit status from test scripts.")), ToolInput(tag="in_merge", input_type=Boolean(optional=True), prefix="--merge", doc=InputDocumentation(doc="Merge test scripts' STDERR with their STDOUT.")), ToolInput(tag="in_recurse", input_type=Boolean(optional=True), prefix="--recurse", doc=InputDocumentation(doc="Recursively descend into directories.")), ToolInput(tag="in_reverse", input_type=Boolean(optional=True), prefix="--reverse", doc=InputDocumentation(doc="Run the tests in reverse order.")), ToolInput(tag="in_suppress_test_output", input_type=Boolean(optional=True), prefix="--quiet", doc=InputDocumentation(doc="Suppress some test output while running tests.")), ToolInput(tag="in_only_print_summary", input_type=Boolean(optional=True), prefix="--QUIET", doc=InputDocumentation(doc="Only print summary results.")), ToolInput(tag="in_parse", input_type=Boolean(optional=True), prefix="--parse", doc=InputDocumentation(doc="Show full list of TAP parse errors, if any.")), ToolInput(tag="in_directives", input_type=Boolean(optional=True), prefix="--directives", doc=InputDocumentation(doc="Only show results with TODO or SKIP directives.")), ToolInput(tag="in_timer", input_type=Boolean(optional=True), prefix="--timer", doc=InputDocumentation(doc="Print elapsed time after each test.")), ToolInput(tag="in_trap", input_type=Boolean(optional=True), prefix="--trap", doc=InputDocumentation(doc="Trap Ctrl-C and print summary on interrupt.")), ToolInput(tag="in_normalize", input_type=Boolean(optional=True), prefix="--normalize", doc=InputDocumentation(doc="Normalize TAP output in verbose output")), ToolInput(tag="in_enable_tainting_checks", input_type=Boolean(optional=True), prefix="-T", doc=InputDocumentation(doc="Enable tainting checks.")), ToolInput(tag="in_enable_tainting_warnings", input_type=Boolean(optional=True), prefix="-t", doc=InputDocumentation(doc="Enable tainting warnings.")), ToolInput(tag="in_enable_fatal_warnings", input_type=Boolean(optional=True), prefix="-W", doc=InputDocumentation(doc="Enable fatal warnings.")), ToolInput(tag="in_enable_warnings", input_type=Boolean(optional=True), prefix="-w", doc=InputDocumentation(doc="Enable warnings.")), ToolInput(tag="in_man", input_type=Boolean(optional=True), prefix="--man", doc=InputDocumentation(doc="Longer manpage for prove")), ToolInput(tag="in_norc", input_type=Boolean(optional=True), prefix="--norc", doc=InputDocumentation(doc="Don't process default .proverc")), ToolInput(tag="in_library_paths_include", input_type=Boolean(optional=True), prefix="-I", doc=InputDocumentation(doc="Library paths to include.")), ToolInput(tag="in_load_plugin_searches", input_type=Boolean(optional=True), prefix="-P", doc=InputDocumentation(doc="Load plugin (searches App::Prove::Plugin::*.)")), ToolInput(tag="in_load_a_module", input_type=Boolean(optional=True), prefix="-M", doc=InputDocumentation(doc="Load a module.")), ToolInput(tag="in_exec", input_type=Boolean(optional=True), prefix="--exec", doc=InputDocumentation(doc="Interpreter to run the tests ('' for compiled\ntests.)")), ToolInput(tag="in_ext", input_type=Boolean(optional=True), prefix="--ext", doc=InputDocumentation(doc="Set the extension for tests (default '.t')")), ToolInput(tag="in_harness", input_type=Boolean(optional=True), prefix="--harness", doc=InputDocumentation(doc="Define test harness to use.  See TAP::Harness.")), ToolInput(tag="in_formatter", input_type=Boolean(optional=True), prefix="--formatter", doc=InputDocumentation(doc="Result formatter to use. See FORMATTERS.")), ToolInput(tag="in_source", input_type=Boolean(optional=True), prefix="--source", doc=InputDocumentation(doc="Load and/or configure a SourceHandler. See\nSOURCE HANDLERS.")), ToolInput(tag="in_archive", input_type=File(optional=True), prefix="--archive", doc=InputDocumentation(doc="Store the resulting TAP in an archive file.")), ToolInput(tag="in_jobs", input_type=Int(optional=True), prefix="--jobs", doc=InputDocumentation(doc="Run N test jobs in parallel (try 9.)")), ToolInput(tag="in_state", input_type=String(optional=True), prefix="--state", doc=InputDocumentation(doc="Control prove's persistent state.")), ToolInput(tag="in_rc", input_type=String(optional=True), prefix="--rc", doc=InputDocumentation(doc="Process options from rcfile")), ToolInput(tag="in_rules", input_type=Boolean(optional=True), prefix="--rules", doc=InputDocumentation(doc="Rules for parallel vs sequential processing.")), ToolInput(tag="in_files", input_type=String(optional=True), position=0, doc=InputDocumentation(doc="")), ToolInput(tag="in_or", input_type=String(optional=True), position=1, doc=InputDocumentation(doc=""))], outputs=[], container=None, version="v0.1.0")


if __name__ == "__main__":
    # or "cwl"
    Prove_V0_1_0().translate("wdl", allow_empty_container=True)

